session: cache align transport base class

Type:refactor

Also remove tx stats. Expectation is that transports will keep track of
them.

Change-Id: I083b328d87d0ad3688b630ddb5ef97827a4dbc2b
Signed-off-by: Florin Coras <fcoras@cisco.com>
diff --git a/src/vnet/session/transport.h b/src/vnet/session/transport.h
index 058a9ae..c4f74eb 100644
--- a/src/vnet/session/transport.h
+++ b/src/vnet/session/transport.h
@@ -237,16 +237,15 @@
 u8 *format_transport_pacer (u8 * s, va_list * args);
 
 /**
  * Update tx byte stats for transport connection
  *
- * If tx pacing is enabled, this also updates pacer bucket to account for the
+ * If tx pacing is enabled, this update pacer bucket to account for the
  * amount of bytes that have been sent.
  *
  * @param tc		transport connection
- * @param pkts		packets recently sent
  * @param bytes		bytes recently sent
  */
-void transport_connection_update_tx_stats (transport_connection_t * tc,
+void transport_connection_update_tx_bytes (transport_connection_t * tc,
 					   u32 bytes);
 
 void
@@ -237,16 +237,15 @@
 
 /**
- * Update tx byte stats for transport connection
+ * Update tx bytes for paced transport connection
  *